Index: chrome/browser/dom_ui/app_launcher_handler.h |
=================================================================== |
--- chrome/browser/dom_ui/app_launcher_handler.h (revision 50261) |
+++ chrome/browser/dom_ui/app_launcher_handler.h (working copy) |
@@ -35,12 +35,15 @@ |
// Populate a dictionary with the information from an extension. |
static void CreateAppInfo(Extension* extension, DictionaryValue* value); |
- // Callback for the "getAll" message. |
+ // Callback for the "getApps" message. |
void HandleGetApps(const Value* value); |
// Callback for the "launch" message. |
void HandleLaunchApp(const Value* value); |
+ // Callback for the "uninstallApp" message. |
+ void HandleUninstallApp(const Value* value); |
+ |
private: |
// Starts the animation of the app icon. |
void AnimateAppIcon(Extension* extension, const gfx::Rect& rect); |
@@ -35,12 +35,15 @@ |
void HandleGetApps(const Value* value); |
- // Callback for the "launch" message. |
+ // Callback for the "launchApp" message. |
void HandleLaunchApp(const Value* value); |